<?php
/**
 * Mobile Basic template for Mobile Joomla! extension
 * https://www.mobilejoomla.com
 *
 * @version        3.2.2
 * @license        GNU/GPL v2 - http://www.gnu.org/licenses/gpl-2.0.html
 * @copyright    (C) 2008-2024 Kuneri Ltd. / Denis Ryabov
 * @date        February 2024
 */
defined('_JEXEC') or die('Restricted access');

jQMHelper::process($this->params);

class jQMHelper
{
    public static $params;

    public static function process($params)
    {
        self::$params = $params;

        self::parseComponentBuffer();

        JFactory::getApplication()->registerEvent('onAfterRender', 'jQMHelper_onAfterRender');
    }

    private static function parseComponentBuffer()
    {
        /** @var JDocumentHtml $document */
        $document = JFactory::getDocument();
        $content = $document->getBuffer('component');

        // pagination plugin
        if (class_exists('plgContentPagenavigation', false)) {
            $content = preg_replace_callback('#<ul class="pagenav">(.*?)</ul>#s', array('jQMHelper', 'pagenav_replacer'), $content);
        }

        // pagebreak plugin
        if (class_exists('plgContentPagebreak', false)) {
            $content = preg_replace_callback('#<div class="pull-right article-index">\s*(?:<h3>(.*?)</h3>)?\s*<ul class="nav nav-tabs nav-stacked">(.*?)</ul>\s*</div>#s', array('jQMHelper', 'pagebreak_toc_replacer'), $content);
            $content = preg_replace_callback('#<div class="pager"><ul><li>(.*?)</li><li>(.*?)</li></ul></div>#s', array('jQMHelper', 'pagebreak_nav_replacer'), $content);
        }

        $document->setBuffer($content, 'component');
    }

    public static function pagenav_replacer($matches)
    {
        $theme = JFactory::getDocument()->params->get('theme_pagination');
        if ($theme) {
            $theme = ' data-theme="' . $theme . '"';
        }
        $inner = $matches[1];
        $inner = preg_replace('#<li class="pagenav-prev">\s*<a href="(.*?)" rel="(?:prev|next)">(.*?)</a>\s*</li>#s', '<a data-role="button" data-inline="true" href="\1" data-direction="reverse">\2</a>', $inner);
        $inner = preg_replace('#<li class="pagenav-next">\s*<a href="(.*?)" rel="(?:prev|next)">(.*?)</a>\s*</li>#s', '<a data-role="button" data-inline="true" href="\1">\2</a>', $inner);
        return '<div data-role="controlgroup" data-type="horizontal"' . $theme . ' class="pagenav">' . $inner . '</div>';
    }

    public static function pagebreak_toc_replacer($matches)
    {
        $tocTitle = $matches[1];
        if (empty($tocTitle)) {
            $tag = JFactory::getLanguage()->getTag();
            $filename = JPATH_ADMINISTRATOR . "/language/$tag/$tag.plg_content_pagebreak.ini";
            if (is_file($filename)) {
                $contents = file_get_contents($filename);
                $contents = str_replace('_QQ_', '"\""', $contents);
                $strings = @parse_ini_string($contents);
                $tocTitle = @$strings['PLG_CONTENT_PAGEBREAK_TOC_LABEL'];
            }
        }
        return
            '<div data-role="collapsible" class="article-index">'
            . '<h3>' . $tocTitle . '</h3>'
            . '<ol data-role="listview" data-inset="true">'
            . $matches[2]
            . '</ol></div>';
    }

    public static function pagebreak_nav_replacer($matches)
    {
        $theme = JFactory::getDocument()->params->get('theme_pagination');
        if ($theme) {
            $theme = ' data-theme="' . $theme . '"';
        }
        $prev = $matches[1];
        $next = $matches[2];
        if (strncmp($prev, '<a ', 3) === 0) {
            $prev = '<a data-role="button" data-inline="true"' . substr($prev, 2);
        } else {
            $prev = '<span data-role="button" data-inline="true" class="ui-btn ui-disabled">' . $prev . '</span>';
        }
        if (strncmp($next, '<a ', 3) === 0) {
            $next = '<a data-role="button" data-inline="true"' . substr($next, 2);
        } else {
            $next = '<span data-role="button" data-inline="true" class="ui-btn ui-disabled">' . $next . '</span>';
        }
        return
            '<div data-role="controlgroup" data-type="horizontal"' . $theme . ' class="pagination pagenav">'
            . $prev . $next
            . '</div>';
    }
}

function jQMHelper_replace_anchors($matches)
{
    /*
        For <a href="link.htm#anchor" target="_blank"> matches contain
            0: <a href="link.htm#anchor" target="_blank">
            1: <a href=
            2: "
            3: link.htm
            4: anchor
            5:  target="_blank">
    */
    if (isset($matches[6]) || preg_match('/\b(data-\w+|onclick)=/i', $matches[1] . $matches[5]) || preg_match('/^\s*javascript:/i', $matches[3])) {
        return $matches[0];
    }
    if ($matches[3]) {
        return $matches[1] . $matches[2] . $matches[3] . $matches[2] . $matches[5];
    }
    return $matches[1] . '"javascript:void(jQuery.mobile.silentScroll(jQuery(\'a[name=' . $matches[4] . '],#' . $matches[4] . '\').get(0).offsetTop))" data-ajax="false"' . $matches[5];
}

function jQMHelper_onAfterRender()
{
    $app = JFactory::getApplication();
    $buffer = $app->getBody();

    // parse hashes
    if (jQMHelper::$params->get('ajax')) {
        $attributes = '(?>\s|[^>\'"\s]+|"[^>"]*?"|\'[^>\']*?\')*?';
        $buffer = preg_replace_callback('@(<a\s(?:' . $attributes . '\s)?href=)([\'"])([^\'"#]*)#([^\'"]+)\2(' . $attributes . '>)|(<script\b.*?</script>)@is', 'jQMHelper_replace_anchors', $buffer);
    }

    if ($buffer) {
        $app->setBody($buffer);
    }

    return true;
}
