<?php
/**
 * Mobile Basic template for Mobile Joomla! extension
 * https://www.mobilejoomla.com
 *
 * @version        3.2.2
 * @license        GNU/GPL v2 - http://www.gnu.org/licenses/gpl-2.0.html
 * @copyright    (C) 2008-2024 Kuneri Ltd. / Denis Ryabov
 * @date        February 2024
 */
defined('_JEXEC') or die('Restricted access');

/** @var $this JDocumentHTML */

/** @var JApplicationSite $app */
$app = JFactory::getApplication();
/** @var MobileJoomla $mj */
$mj_list = $app->triggerEvent('onGetMobileJoomla');
$mj = array_pop($mj_list);
if ($mj === null) {
    die('Enable System - Mobile Core plugin!');
}

include_once __DIR__ . '/includes/mjjqmframework.php';
include_once __DIR__ . '/includes/mj.renderer.php';
MJJqmFramework::getInstance($this);

$enable_backbutton = true;
// don't show Back button on devices with hardware back button
if ($this->params->get('headerhideback') && preg_match('/Android|BlackBerry/', @$_SERVER['HTTP_USER_AGENT'])) {
    $enable_backbutton = false;
}

//params
$theme_page = $this->params->get('theme_page');
$theme_header = $this->params->get('theme_header');
$theme_footer = $this->params->get('theme_footer');

$app = JFactory::getApplication();
$doc = JFactory::getDocument();

$enhance_content = true;
if ($this->params->get('enhance')) {
    $option = $app->input->getCmd('option');
    $woEnhancing = explode(',', $this->params->get('enhance_coms', ''));
    if (in_array($option, $woEnhancing, true)) {
        $enhance_content = false;
    }
}

$base = $this->baseurl . '/templates/' . $this->template;
$home = $this->baseurl . '/';
$base_full = JUri::base() . 'templates/' . $this->template;

/** @var MjDevice $mjDevice */
$mjDevice = $mj->device; // used by common-headers.php
$markup = $mjDevice->markup;
if ($markup != $mjDevice->default_markup) {
    $home .= '?device=' . $markup;
}

include_once __DIR__ . '/includes/process.php';

// @todo Move all include statement to the top of the file
include_once __DIR__ . '/mj_boot.php';
$toolbar = MjToolbar::getInstance();

if ($mj->isHome() && !$app->input->getInt('limitstart')) {
    $logo = $this->params->get('logo');
    if ($logo === '' || $logo === '-') {
        $this->params->set('title', 1);
    } else {
        if (strpos($logo, '#') !== false) {
            $logo = explode('#', $logo, 2)[0];
        }
        if (strpos($logo, '://') === false) {
            $logo = JUri::root(true) . '/' . $logo;
        }

    }

    $img_attrs = ' ress-nowrap ress-fullwidth';
    if ($mj->getParam('img_lazyload')) {
        $img_attrs .= ' ress-nolazy';
    }
    if (!$mj->getParam('ress_optimize')) {
        $img_attrs = '';
    }

    switch ($this->params->get('title')) {
        case 2:
            $page_header = '<img src="' . $logo . '"' . $img_attrs . ' alt="">';
            break;
        case 3:
            $page_header = '<img src="' . $logo . '"' . $img_attrs . ' alt=""> ' . $app->getCfg('sitename');
            break;
        case 1:
        default:
            $page_header = $app->getCfg('sitename');
            break;
    }
} else {
    $pos = $this->params->get('headerback');
    if ($pos !== 'none' && $enable_backbutton && !$toolbar->isBackButtonHidden()) {
        $toolbar->prependButton($pos, 'javascript:history.back()', 'left',
            JText::_('TPL_MOBILE_JQM__BACK'), array('attrib' => 'data-rel="back" data-iconpos="notext"', 'class' => 'back')
        );
    }

    $pos = $this->params->get('headerhome');
    if ($pos !== 'none' && !$toolbar->isHomeButtonHidden()) {
        $toolbar->prependButton($pos, $home, 'home',
            JText::_('TPL_MOBILE_JQM__HOME'), array('attrib' => 'data-direction="reverse" data-iconpos="notext"', 'class' => 'home')
        );
    }

    $page_header = $toolbar->getTitle();
    if ($page_header === null) {
        $page_header = $doc->getTitle();
    }
}

$pos = $this->params->get('panelposition');
$hasPanel = ($pos !== 'none') && ($this->countModules('mj_panel') > 0);
if ($hasPanel) {
    $panelId = 'panel' . mt_rand();
    $toolbar->appendButton($pos, '#' . $panelId, 'bars', JText::_('TPL_MOBILE_JQM__MENUBTN'), array('attrib' => 'data-iconpos="notext"', 'class' => 'panel'));
}

// fonts preloading
$theme = $this->params->get('theme');

?><!doctype html>
<html>
<head>
    <?php include __DIR__ . '/includes/common-headers.php'; ?>
    <jdoc:include type="mjhead"/>
</head>
<body>
<div data-role="page"<?php
if ($theme_page) {
    echo " data-theme=\"$theme_page\"";
}
$class = '';
if ($mj->isHome()) {
    $class .= " home";
}
if ($hasPanel && $this->params->get('paneldisplay') === 'push') {
    $class .= " ui-responsive-panel";
}
if (!empty($class)) {
    echo ' class="' . trim($class) . '"';
}
?>>
    <jdoc:include type="mjbody"/>
<?php
    $headermode = $this->params->get($mj->isHome() ? 'homeheadermode' : 'headermode');
    if ($headermode !== 'hide') :
        $attrs = '';
        if ($theme_header) {
            $attrs .= " data-theme=\"$theme_header\"";
        }
        switch ($headermode) {
            case 'fixed':
                $attrs .= ' data-position="fixed"';
                break;
            case 'fullscreen':
                $attrs .= ' data-position="fixed" data-fullscreen="true"';
                break;
        }
    ?><header class="header" data-role="header"<?php echo $attrs; ?>>
        <h1><?php echo $page_header; ?></h1>
<?php
        include_once __DIR__ . '/includes/toolbar.php';

        $iconClass = false ? ' ui-icon-alt' : ''; /* inverse icons in header */

        $leftButtons = $toolbar->getButtons('left');
        if (count($leftButtons)):
            ?><div class="ui-btn-left<?php echo $iconClass; ?>"><?php echo renderToolbar($leftButtons); ?></div><?php
        endif;

        $rightButtons = $toolbar->getButtons('right');
        if (count($rightButtons)):
            ?><div class="ui-btn-right<?php echo $iconClass; ?>"><?php echo renderToolbar(array_reverse($rightButtons)); ?></div><?php
        endif;
    ?></header><?php /* div[data-role=header] */ ?>
    <?php endif; ?>
    <main class="ui-content" data-role="main">
        <?php

        if ($this->countModules('mj_top') > 0):
            ?><div class="posmj_top"><jdoc:include type="modules" name="mj_top" style="mobile"/></div><?php
        endif;

        ?><div class="content"><?php

            if ($this->countModules('mj_top2') > 0):
                ?><div class="posmj_top2"><jdoc:include type="modules" name="mj_top2" style="mobile"/></div><?php
            endif;

            ?><jdoc:include type="message"/><?php

            if ($this->countModules('mj_top3') > 0):
                ?><div class="posmj_top3"><jdoc:include type="modules" name="mj_top3" style="mobile"/></div><?php
            endif;

            ?><div class="jcomponent"<?php if (!$enhance_content) {
                echo ' data-enhance="false"';
            } ?>><jdoc:include type="component"/></div><?php

            if ($this->countModules('mj_middle') > 0):
                ?><div class="posmj_middle"><jdoc:include type="modules" name="mj_middle" style="mobile"/></div><?php
            endif;

            ?>
        </div><?php /* div.content */ ?>
        <?php

        if ($this->countModules('mj_middle2') > 0):
            ?><div class="posmj_middle2"><jdoc:include type="modules" name="mj_middle2" style="mobile"/></div><?php
        endif;

        ?>
    </main><?php /* div[data-role=content] */ ?>
    <?php
    $hasFooter = $this->countModules('mj_footer') ||
        $this->countModules('mj_footer2');
    $footermode = $this->params->get('footermode');
    if ($footermode !== 'hide' && $hasFooter) :
        $attrs = '';
        if ($theme_footer) {
            $attrs .= " data-theme=\"$theme_footer\"";
        }
        switch ($footermode) {
            case 'fixed':
                $attrs .= ' data-position="fixed"';
                break;
            case 'fullscreen':
                $attrs .= ' data-position="fixed" data-fullscreen="true"';
                break;
        }
        ?>
        <footer class="footer" data-role="footer"<?php echo $attrs; ?>><?php

        $results = $app->triggerEvent('onMobileJoomlaAdCheck', array());
        if (!in_array('f3da4a6dd8f15c9170572d18838c841e', array_map('md5', $results), true)) {
            ?><div class="mj-sponsor-placement"><script type="text/javascript" defer ress-nomerge<?php
            ?> src="//ads.mobilejoomla.com/ad3.js?domain=<?php echo $_SERVER['HTTP_HOST']; ?>"></script></div><?php
        }

        if ($this->countModules('mj_footer') > 0):
            ?><div class="posmj_footer"><jdoc:include type="modules" name="mj_footer" style="mobile"/></div><?php
        endif;

        if ($this->countModules('mj_footer2') > 0):
            ?><div class="posmj_footer2"><jdoc:include type="modules" name="mj_footer2" style="mobile"/></div><?php
        endif;

        ?></footer><?php /* div[data-role=footer] */ ?>
    <?php
    endif;

    if ($hasPanel):
        $attrs = '';
        if ($this->params->get('panelposition') !== 'left') {
            $attrs .= ' data-position="right"';
        }
        $display = $this->params->get('paneldisplay');
        if ($display !== 'reveal') {
            $attrs .= ' data-display="' . $display . '"';
        }
        if ($this->params->get('panelfixed')) {
            $attrs .= ' data-position-fixed="true"';
        }
        ?><aside data-role="panel"<?php echo $attrs; ?> id="<?php echo $panelId; ?>"><?php
        ?><div class="posmj_panel"><jdoc:include type="modules" name="mj_panel" style="mobile"/></div><?php
        ?></aside><?php /* div[data-role=panel] */
    endif;
    ?>
</div><?php /* div[data-role=page] */ ?>
</body>
</html>